==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/cy_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Gwaith",
    "Personal" : "Personol",
    "Mail" : "E-bost",
    "Connecting" : "Yn cysylltu",
    "Save" : "Cadw",
    "Connect" : "Cysylltu",
    "Auto" : "Awto",
    "Name" : "Enw",
    "Password" : "Cyfrinair",
    "Manual" : "Â Llaw",
    "IMAP Settings" : "Gosodiadau IMAP",
    "IMAP Host" : "Gwesteiwr IMAP",
    "IMAP Security" : "Diogelwch IMAP",
    "None" : "Dim",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porth IMAP",
    "IMAP User" : "Defnyddiwr IMAP",
    "IMAP Password" : "Cyfrinair IMAP",
    "SMTP Settings" : "Gosodiadau SMTP",
    "SMTP Host" : "Gwesteiwr SMTP",
    "SMTP Security" : "Diogelwch SMTP",
    "SMTP Port" : "Porth SMTP",
    "SMTP User" : "Defnyddiwr SMTP",
    "SMTP Password" : "Cyfrinair SMTP",
    "Signature" : "Llofnod",
    "Mail server" : "Gweinydd e-bost",
    "Go back" : "Nôl",
    "Email address" : "Cyfeiriad e-bost",
    "Cancel" : "Diddymu",
    "General" : "Cyffredinol",
    "Add mail account" : "Ychwanegu cyfrif post",
    "List" : "Rhestr",
    "Newest first" : "Diweddaraf gyntaf",
    "Register" : "Cofrestru",
    "Security" : "Diogelwch",
    "About" : "Ynglyn â",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Compose new message" : "Ysgrifennu Neges _Newydd",
    "Newer message" : "Neges diweddarach",
    "Older message" : "Neges hyn",
    "Toggle star" : "Toglo seren",
    "Toggle unread" : "Toglo heb ei darllen",
    "Archive" : "Archif",
    "Delete" : "Dileu",
    "Search" : "Chwilio",
    "Send" : "Anfon",
    "Refresh" : "Ail-lwytho",
    "Ok" : "Iawn",
    "Subject" : "Pwnc",
    "Saving draft …" : "Yn cadw drafft …",
    "Draft saved" : "Cadwyd y drafft",
    "Upload attachment" : "Llwytho atodiad",
    "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
    "Choose" : "Dewisa",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "Confirm" : "Cadarnhau",
    "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
    "Favorite" : "Ffefryn",
    "Back" : "Nôl",
    "Report this bug" : "Cofnodi'r gwall",
    "Create event" : "Creu digwyddiad",
    "All day" : "Drwy'r dydd",
    "Attendees" : "Mynychwyr",
    "Description" : "Disgrifiad",
    "Create" : "Creu",
    "Select" : "Select",
    "Comment" : "Sylw",
    "Accept" : "Derbyn",
    "Decline" : "Gwrthod",
    "Remove" : "Gwaredu",
    "Today" : "Heddiw",
    "Other" : "Arall",
    "Translate" : "Cyfieithu",
    "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
    "Import into calendar" : "Mewnforio i'r calendr",
    "Download attachment" : "Llwytho'r atodiad i lawr",
    "Save to Files" : "Cadw i Ffeiliau",
    "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
    "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
    "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
    "Move" : "Symud",
    "Remove account" : "Dileu cyfrif",
    "Add folder" : "Ychwanegu ffolder",
    "Show all folders" : "Dangos pob ffolder",
    "Collapse folders" : "Cwympo ffolderi",
    "Loading …" : "Yn llwytho …",
    "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
    "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
    "Add subfolder" : "Ychwanegu is-ffolder",
    "Rename" : "Ailenwi",
    "New message" : "Neges newydd",
    "Error sending your message" : "Gwall wrth anfon eich neges",
    "Retry" : "Ceisio eto",
    "Add" : "Ychwanegu",
    "Close" : "Cau",
    "Date" : "Date",
    "Tags" : "Tagiau",
    "Custom" : "Cyfaddas",
    "Not found" : "Heb ei ganfod",
    "Untitled event" : "Digwyddiad di-deitl",
    "(organizer)" : "(trefnydd)",
    "Recipient" : "Derbynnydd",
    "Help" : "Cymorth",
    "Actions" : "Gweithredoedd",
    "delete" : "dileu",
    "Edit" : "Golygu",
    "User" : "Defnyddwyr",
    "Certificate" : "Tystysgrif",
    "Group" : "Grŵp",
    "Shared" : "Rhannwyd",
    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
    "All" : "Popeth",
    "Drafts" : "Drafftiau",
    "Favorites" : "Ffefrynnau",
    "All inboxes" : "Pob blwch derbyn",
    "Inbox" : "Blwch Derbyn",
    "Junk" : "Sothach",
    "Sent" : "Anfonwyd",
    "Trash" : "Sbwriel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["oddi wrth {from}","oddi wrth {from}","oddi wrth {from}","oddi wrth {from}"],
    "Nextcloud Mail" : "E-bost Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
    "Could not load your message" : "Methu llwytho'ch neges",
    "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
    "Could not load the message" : "Methu llwytho'r neges",
    "Error loading message" : "Gwall wrth lwytho neges",
    "Forwarding to %s" : "Anfon ymlaen at %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
    "Redirect" : "Ailgyfeirio",
    "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
    "Continue to %s" : "Parhau i %s",
    "Accounts" : "Accounts",
    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-app-mail-5.5.15-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/cy_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Gwaith",
    "Personal" : "Personol",
    "Mail" : "E-bost",
    "Connecting" : "Yn cysylltu",
    "Save" : "Cadw",
    "Connect" : "Cysylltu",
    "Auto" : "Awto",
    "Name" : "Enw",
    "Password" : "Cyfrinair",
    "Manual" : "Â Llaw",
    "IMAP Settings" : "Gosodiadau IMAP",
    "IMAP Host" : "Gwesteiwr IMAP",
    "IMAP Security" : "Diogelwch IMAP",
    "None" : "Dim",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porth IMAP",
    "IMAP User" : "Defnyddiwr IMAP",
    "IMAP Password" : "Cyfrinair IMAP",
    "SMTP Settings" : "Gosodiadau SMTP",
    "SMTP Host" : "Gwesteiwr SMTP",
    "SMTP Security" : "Diogelwch SMTP",
    "SMTP Port" : "Porth SMTP",
    "SMTP User" : "Defnyddiwr SMTP",
    "SMTP Password" : "Cyfrinair SMTP",
    "Signature" : "Llofnod",
    "Mail server" : "Gweinydd e-bost",
    "Go back" : "Nôl",
    "Email address" : "Cyfeiriad e-bost",
    "Cancel" : "Diddymu",
    "General" : "Cyffredinol",
    "Add mail account" : "Ychwanegu cyfrif post",
    "List" : "Rhestr",
    "Newest first" : "Diweddaraf gyntaf",
    "Oldest first" : "Hynaf gyntaf",
    "Register" : "Cofrestru",
    "Security" : "Diogelwch",
    "Manage certificates" : "Rheoli tystysgrifau",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Compose new message" : "Ysgrifennu Neges _Newydd",
    "Newer message" : "Neges diweddarach",
    "Older message" : "Neges hyn",
    "Toggle star" : "Toglo seren",
    "Toggle unread" : "Toglo heb ei darllen",
    "Archive" : "Archif",
    "Delete" : "Dileu",
    "Search" : "Chwilio",
    "Send" : "Anfon",
    "Refresh" : "Ail-lwytho",
    "About" : "Ynglyn â",
    "Ok" : "Iawn",
    "Subject" : "Pwnc",
    "Draft saved" : "Cadwyd y drafft",
    "Upload attachment" : "Llwytho atodiad",
    "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
    "Choose" : "Dewisa",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "Confirm" : "Cadarnhau",
    "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
    "Favorite" : "Ffefryn",
    "Back" : "Nôl",
    "Report this bug" : "Cofnodi'r gwall",
    "Create event" : "Creu digwyddiad",
    "All day" : "Drwy'r dydd",
    "Attendees" : "Mynychwyr",
    "Description" : "Disgrifiad",
    "Create" : "Creu",
    "Select" : "Select",
    "Comment" : "Sylw",
    "Accept" : "Derbyn",
    "Decline" : "Gwrthod",
    "Remove" : "Gwaredu",
    "Today" : "Heddiw",
    "Other" : "Arall",
    "Translate" : "Cyfieithu",
    "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
    "Import into calendar" : "Mewnforio i'r calendr",
    "Download attachment" : "Llwytho'r atodiad i lawr",
    "Save to Files" : "Cadw i Ffeiliau",
    "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
    "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
    "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
    "Move" : "Symud",
    "Remove account" : "Dileu cyfrif",
    "Add folder" : "Ychwanegu ffolder",
    "Show all folders" : "Dangos pob ffolder",
    "Collapse folders" : "Cwympo ffolderi",
    "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
    "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
    "Add subfolder" : "Ychwanegu is-ffolder",
    "Rename" : "Ailenwi",
    "New message" : "Neges newydd",
    "Error sending your message" : "Gwall wrth anfon eich neges",
    "Retry" : "Ceisio eto",
    "Add" : "Ychwanegu",
    "Close" : "Cau",
    "Date" : "Date",
    "Tags" : "Tagiau",
    "Custom" : "Cyfaddas",
    "Not found" : "Heb ei ganfod",
    "Untitled event" : "Digwyddiad di-deitl",
    "(organizer)" : "(trefnydd)",
    "Recipient" : "Derbynnydd",
    "Help" : "Cymorth",
    "Actions" : "Gweithredoedd",
    "delete" : "dileu",
    "Edit" : "Golygu",
    "User" : "Defnyddwyr",
    "Certificate" : "Tystysgrif",
    "Group" : "Grŵp",
    "Shared" : "Rhannwyd",
    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
    "All" : "Popeth",
    "Drafts" : "Drafftiau",
    "Favorites" : "Ffefrynnau",
    "All inboxes" : "Pob blwch derbyn",
    "Inbox" : "Blwch Derbyn",
    "Junk" : "Sothach",
    "Sent" : "Anfonwyd",
    "Trash" : "Sbwriel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["oddi wrth {from}","oddi wrth {from}","oddi wrth {from}","oddi wrth {from}"],
    "Nextcloud Mail" : "E-bost Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
    "Could not load your message" : "Methu llwytho'ch neges",
    "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
    "Could not load the message" : "Methu llwytho'r neges",
    "Error loading message" : "Gwall wrth lwytho neges",
    "Forwarding to %s" : "Anfon ymlaen at %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
    "Redirect" : "Ailgyfeirio",
    "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
    "Continue to %s" : "Parhau i %s",
    "Accounts" : "Accounts",
    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
    "Saving draft …" : "Yn cadw drafft …",
    "Loading …" : "Yn llwytho …"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
